@@ -42,16 +42,6 @@ def web(ctx_obj):
         execute(start_uwsgi_command(settings=ctx_obj['settings'], port=80))
 
 
-@click.command()
-@click.pass_obj
-def worker(ctx_obj):
-    """
-    coming soon: launch the background worker
-    """
-    # TODO: celery worker startup, once available
-    pass
-
-
 @click.command()
 @click.pass_obj
 def migrate(ctx_obj):
@@ -92,7 +82,6 @@ def main(ctx, verbose):
 
 
 main.add_command(web)
-main.add_command(worker)
 main.add_command(migrate)
 
 
